"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LoggingBillingAccountBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    bucket_id: builtins.str
    description: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account", b"billing_account", "bucket_id", b"bucket_id", "description", b"description", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingBillingAccountBucketConfig = LoggingBillingAccountBucketConfig

@typing_extensions.final
class LoggingBillingAccountExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account", b"billing_account", "description", b"description", "disabled", b"disabled", "filter", b"filter", "id", b"id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___LoggingBillingAccountExclusion = LoggingBillingAccountExclusion

@typing_extensions.final
class LoggingBillingAccountSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingBillingAccountSinkXBigqueryOptions = LoggingBillingAccountSinkXBigqueryOptions

@typing_extensions.final
class LoggingBillingAccountSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingBillingAccountSinkXExclusions = LoggingBillingAccountSinkXExclusions

@typing_extensions.final
class LoggingBillingAccountSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingBillingAccountSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingBillingAccountSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingBillingAccountSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingBillingAccountSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "billing_account", b"billing_account", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "id", b"id", "name", b"name", "resource_info", b"resource_info", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingBillingAccountSink = LoggingBillingAccountSink

@typing_extensions.final
class LoggingFolderBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    description: builtins.str
    folder: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_id", b"bucket_id", "description", b"description", "folder", b"folder", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingFolderBucketConfig = LoggingFolderBucketConfig

@typing_extensions.final
class LoggingFolderExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    folder: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "folder", b"folder", "id", b"id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___LoggingFolderExclusion = LoggingFolderExclusion

@typing_extensions.final
class LoggingFolderSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingFolderSinkXBigqueryOptions = LoggingFolderSinkXBigqueryOptions

@typing_extensions.final
class LoggingFolderSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingFolderSinkXExclusions = LoggingFolderSinkXExclusions

@typing_extensions.final
class LoggingFolderSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INCLUDE_CHILDREN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    folder: builtins.str
    id: builtins.str
    include_children: builtins.bool
    name: builtins.str
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingFolderSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingFolderSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        folder: builtins.str = ...,
        id: builtins.str = ...,
        include_children: builtins.bool = ...,
        name: builtins.str = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingFolderSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingFolderSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "folder", b"folder", "id", b"id", "include_children", b"include_children", "name", b"name", "resource_info", b"resource_info", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingFolderSink = LoggingFolderSink

@typing_extensions.final
class LoggingLogViewXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___LoggingLogViewXTimeouts = LoggingLogViewXTimeouts

@typing_extensions.final
class LoggingLogView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    create_time: builtins.str
    description: builtins.str
    filter: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    parent: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___LoggingLogViewXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___LoggingLogViewXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "create_time", b"create_time", "description", b"description", "filter", b"filter", "id", b"id", "location", b"location", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___LoggingLogView = LoggingLogView

@typing_extensions.final
class LoggingMetricXBucketOptionsXExplicitBuckets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDS_FIELD_NUMBER: builtins.int
    @property
    def bounds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        bounds: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bounds", b"bounds"]) -> None: ...

global___LoggingMetricXBucketOptionsXExplicitBuckets = LoggingMetricXBucketOptionsXExplicitBuckets

@typing_extensions.final
class LoggingMetricXBucketOptionsXExponentialBuckets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROWTH_FACTOR_FIELD_NUMBER: builtins.int
    NUM_FINITE_BUCKETS_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    growth_factor: builtins.float
    num_finite_buckets: builtins.float
    scale: builtins.float
    def __init__(
        self,
        *,
        growth_factor: builtins.float = ...,
        num_finite_buckets: builtins.float = ...,
        scale: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["growth_factor", b"growth_factor", "num_finite_buckets", b"num_finite_buckets", "scale", b"scale"]) -> None: ...

global___LoggingMetricXBucketOptionsXExponentialBuckets = LoggingMetricXBucketOptionsXExponentialBuckets

@typing_extensions.final
class LoggingMetricXBucketOptionsXLinearBuckets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_FINITE_BUCKETS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    num_finite_buckets: builtins.float
    offset: builtins.float
    width: builtins.float
    def __init__(
        self,
        *,
        num_finite_buckets: builtins.float = ...,
        offset: builtins.float = ...,
        width: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_finite_buckets", b"num_finite_buckets", "offset", b"offset", "width", b"width"]) -> None: ...

global___LoggingMetricXBucketOptionsXLinearBuckets = LoggingMetricXBucketOptionsXLinearBuckets

@typing_extensions.final
class LoggingMetricXBucketOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPLICIT_BUCKETS_FIELD_NUMBER: builtins.int
    EXPONENTIAL_BUCKETS_FIELD_NUMBER: builtins.int
    LINEAR_BUCKETS_FIELD_NUMBER: builtins.int
    @property
    def explicit_buckets(self) -> global___LoggingMetricXBucketOptionsXExplicitBuckets: ...
    @property
    def exponential_buckets(self) -> global___LoggingMetricXBucketOptionsXExponentialBuckets: ...
    @property
    def linear_buckets(self) -> global___LoggingMetricXBucketOptionsXLinearBuckets: ...
    def __init__(
        self,
        *,
        explicit_buckets: global___LoggingMetricXBucketOptionsXExplicitBuckets | None = ...,
        exponential_buckets: global___LoggingMetricXBucketOptionsXExponentialBuckets | None = ...,
        linear_buckets: global___LoggingMetricXBucketOptionsXLinearBuckets | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["explicit_buckets", b"explicit_buckets", "exponential_buckets", b"exponential_buckets", "linear_buckets", b"linear_buckets"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["explicit_buckets", b"explicit_buckets", "exponential_buckets", b"exponential_buckets", "linear_buckets", b"linear_buckets"]) -> None: ...

global___LoggingMetricXBucketOptions = LoggingMetricXBucketOptions

@typing_extensions.final
class LoggingMetricXMetricDescriptorXLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    description: builtins.str
    key: builtins.str
    value_type: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        key: builtins.str = ...,
        value_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "key", b"key", "value_type", b"value_type"]) -> None: ...

global___LoggingMetricXMetricDescriptorXLabels = LoggingMetricXMetricDescriptorXLabels

@typing_extensions.final
class LoggingMetricXMetricDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    METRIC_KIND_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    metric_kind: builtins.str
    unit: builtins.str
    value_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingMetricXMetricDescriptorXLabels]: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        metric_kind: builtins.str = ...,
        unit: builtins.str = ...,
        value_type: builtins.str = ...,
        labels: collections.abc.Iterable[global___LoggingMetricXMetricDescriptorXLabels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "labels", b"labels", "metric_kind", b"metric_kind", "unit", b"unit", "value_type", b"value_type"]) -> None: ...

global___LoggingMetricXMetricDescriptor = LoggingMetricXMetricDescriptor

@typing_extensions.final
class LoggingMetricXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___LoggingMetricXTimeouts = LoggingMetricXTimeouts

@typing_extensions.final
class LoggingMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelExtractorsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABEL_EXTRACTORS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    VALUE_EXTRACTOR_FIELD_NUMBER: builtins.int
    BUCKET_OPTIONS_FIELD_NUMBER: builtins.int
    METRIC_DESCRIPTOR_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    filter: builtins.str
    id: builtins.str
    @property
    def label_extractors(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    value_extractor: builtins.str
    @property
    def bucket_options(self) -> global___LoggingMetricXBucketOptions: ...
    @property
    def metric_descriptor(self) -> global___LoggingMetricXMetricDescriptor: ...
    @property
    def timeouts(self) -> global___LoggingMetricXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        label_extractors: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        value_extractor: builtins.str = ...,
        bucket_options: global___LoggingMetricXBucketOptions | None = ...,
        metric_descriptor: global___LoggingMetricXMetricDescriptor | None = ...,
        timeouts: global___LoggingMetricXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bucket_options", b"bucket_options", "metric_descriptor", b"metric_descriptor", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_options", b"bucket_options", "description", b"description", "filter", b"filter", "id", b"id", "label_extractors", b"label_extractors", "metric_descriptor", b"metric_descriptor", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "value_extractor", b"value_extractor"]) -> None: ...

global___LoggingMetric = LoggingMetric

@typing_extensions.final
class LoggingOrganizationBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    description: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    organization: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        organization: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_id", b"bucket_id", "description", b"description", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "organization", b"organization", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingOrganizationBucketConfig = LoggingOrganizationBucketConfig

@typing_extensions.final
class LoggingOrganizationExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    org_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "id", b"id", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info"]) -> None: ...

global___LoggingOrganizationExclusion = LoggingOrganizationExclusion

@typing_extensions.final
class LoggingOrganizationSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingOrganizationSinkXBigqueryOptions = LoggingOrganizationSinkXBigqueryOptions

@typing_extensions.final
class LoggingOrganizationSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingOrganizationSinkXExclusions = LoggingOrganizationSinkXExclusions

@typing_extensions.final
class LoggingOrganizationSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INCLUDE_CHILDREN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    include_children: builtins.bool
    name: builtins.str
    org_id: builtins.str
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingOrganizationSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingOrganizationSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        include_children: builtins.bool = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingOrganizationSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingOrganizationSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "id", b"id", "include_children", b"include_children", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingOrganizationSink = LoggingOrganizationSink

@typing_extensions.final
class LoggingProjectBucketConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LIFECYCLE_STATE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RETENTION_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    description: builtins.str
    id: builtins.str
    lifecycle_state: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    retention_days: builtins.float
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        lifecycle_state: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        retention_days: builtins.float = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_id", b"bucket_id", "description", b"description", "id", b"id", "lifecycle_state", b"lifecycle_state", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "retention_days", b"retention_days"]) -> None: ...

global___LoggingProjectBucketConfig = LoggingProjectBucketConfig

@typing_extensions.final
class LoggingProjectExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___LoggingProjectExclusion = LoggingProjectExclusion

@typing_extensions.final
class LoggingProjectSinkXBigqueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_PARTITIONED_TABLES_FIELD_NUMBER: builtins.int
    use_partitioned_tables: builtins.bool
    def __init__(
        self,
        *,
        use_partitioned_tables: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_partitioned_tables", b"use_partitioned_tables"]) -> None: ...

global___LoggingProjectSinkXBigqueryOptions = LoggingProjectSinkXBigqueryOptions

@typing_extensions.final
class LoggingProjectSinkXExclusions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "filter", b"filter", "name", b"name"]) -> None: ...

global___LoggingProjectSinkXExclusions = LoggingProjectSinkXExclusions

@typing_extensions.final
class LoggingProjectSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UNIQUE_WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    WRITER_IDENTITY_FIELD_NUMBER: builtins.int
    BIGQUERY_OPTIONS_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    destination: builtins.str
    disabled: builtins.bool
    filter: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    unique_writer_identity: builtins.bool
    writer_identity: builtins.str
    @property
    def bigquery_options(self) -> global___LoggingProjectSinkXBigqueryOptions: ...
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoggingProjectSinkXExclusions]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        destination: builtins.str = ...,
        disabled: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        unique_writer_identity: builtins.bool = ...,
        writer_identity: builtins.str = ...,
        bigquery_options: global___LoggingProjectSinkXBigqueryOptions | None = ...,
        exclusions: collections.abc.Iterable[global___LoggingProjectSinkXExclusions] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_options", b"bigquery_options", "description", b"description", "destination", b"destination", "disabled", b"disabled", "exclusions", b"exclusions", "filter", b"filter", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "unique_writer_identity", b"unique_writer_identity", "writer_identity", b"writer_identity"]) -> None: ...

global___LoggingProjectSink = LoggingProjectSink



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_virtualNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIRTUAL_NETWORKS_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORKS_SUBNETS_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORKS_VIRTUAL_NETWORK_PEERINGS_FIELD_NUMBER: builtins.int
    @property
    def virtual_networks(self) -> global___VirtualNetworks: ...
    @property
    def virtual_networks_subnets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworksSubnets]: ...
    @property
    def virtual_networks_virtual_network_peerings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworksVirtualNetworkPeerings]: ...
    def __init__(
        self,
        *,
        virtual_networks: global___VirtualNetworks | None = ...,
        virtual_networks_subnets: collections.abc.Iterable[global___VirtualNetworksSubnets] | None = ...,
        virtual_networks_virtual_network_peerings: collections.abc.Iterable[global___VirtualNetworksVirtualNetworkPeerings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["virtual_networks", b"virtual_networks"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["virtual_networks", b"virtual_networks", "virtual_networks_subnets", b"virtual_networks_subnets", "virtual_networks_virtual_network_peerings", b"virtual_networks_virtual_network_peerings"]) -> None: ...

global___Microsoft_Network_virtualNetworks = Microsoft_Network_virtualNetworks

@typing_extensions.final
class NetworkSecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___NetworkSecurityGroup = NetworkSecurityGroup

@typing_extensions.final
class RouteTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___RouteTable = RouteTable

@typing_extensions.final
class NatGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___NatGateways = NatGateways

@typing_extensions.final
class DdosProtectionPlan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DdosProtectionPlan = DdosProtectionPlan

@typing_extensions.final
class VirtualNetworksVirtualNetworkPeerings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOW_VIRTUAL_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    ALLOW_FORWARDED_TRAFFIC_FIELD_NUMBER: builtins.int
    ALLOW_GATEWAY_TRANSIT_FIELD_NUMBER: builtins.int
    USE_REMOTE_GATEWAYS_FIELD_NUMBER: builtins.int
    REMOTE_VIRTUAL_NETWORK_FIELD_NUMBER: builtins.int
    REMOTE_ADDRESS_SPACE_FIELD_NUMBER: builtins.int
    REMOTE_BGP_COMMUNITIES_FIELD_NUMBER: builtins.int
    PEERING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    allow_virtual_network_access: builtins.bool
    allow_forwarded_traffic: builtins.bool
    allow_gateway_transit: builtins.bool
    use_remote_gateways: builtins.bool
    remote_virtual_network: builtins.str
    @property
    def remote_address_space(self) -> global___AddressSpace: ...
    @property
    def remote_bgp_communities(self) -> global___VirtualNetworkBgpCommunities: ...
    peering_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        allow_virtual_network_access: builtins.bool = ...,
        allow_forwarded_traffic: builtins.bool = ...,
        allow_gateway_transit: builtins.bool = ...,
        use_remote_gateways: builtins.bool = ...,
        remote_virtual_network: builtins.str = ...,
        remote_address_space: global___AddressSpace | None = ...,
        remote_bgp_communities: global___VirtualNetworkBgpCommunities | None = ...,
        peering_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["remote_address_space", b"remote_address_space", "remote_bgp_communities", b"remote_bgp_communities", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_forwarded_traffic", b"allow_forwarded_traffic", "allow_gateway_transit", b"allow_gateway_transit", "allow_virtual_network_access", b"allow_virtual_network_access", "name", b"name", "peering_state", b"peering_state", "remote_address_space", b"remote_address_space", "remote_bgp_communities", b"remote_bgp_communities", "remote_virtual_network", b"remote_virtual_network", "resource_info", b"resource_info", "use_remote_gateways", b"use_remote_gateways"]) -> None: ...

global___VirtualNetworksVirtualNetworkPeerings = VirtualNetworksVirtualNetworkPeerings

@typing_extensions.final
class VirtualNetworksSubnets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    NETWORK_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_FIELD_NUMBER: builtins.int
    NAT_GATEWAY_FIELD_NUMBER: builtins.int
    SERVICE_ENDPOINTS_FIELD_NUMBER: builtins.int
    SERVICE_ENDPOINT_POLICIES_FIELD_NUMBER: builtins.int
    IP_ALLOCATIONS_FIELD_NUMBER: builtins.int
    DELEGATIONS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_NETWORK_POLICIES_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_NETWORK_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    address_prefix: builtins.str
    @property
    def address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def network_security_group(self) -> global___NetworkSecurityGroup: ...
    @property
    def route_table(self) -> global___RouteTable: ...
    nat_gateway: builtins.str
    @property
    def service_endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceEndpointPropertiesFormat]: ...
    @property
    def service_endpoint_policies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ip_allocations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Delegation]: ...
    private_endpoint_network_policies: builtins.str
    private_link_service_network_policies: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        address_prefix: builtins.str = ...,
        address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        network_security_group: global___NetworkSecurityGroup | None = ...,
        route_table: global___RouteTable | None = ...,
        nat_gateway: builtins.str = ...,
        service_endpoints: collections.abc.Iterable[global___ServiceEndpointPropertiesFormat] | None = ...,
        service_endpoint_policies: collections.abc.Iterable[builtins.str] | None = ...,
        ip_allocations: collections.abc.Iterable[builtins.str] | None = ...,
        delegations: collections.abc.Iterable[global___Delegation] | None = ...,
        private_endpoint_network_policies: builtins.str = ...,
        private_link_service_network_policies: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_security_group", b"network_security_group", "resource_info", b"resource_info", "route_table", b"route_table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_prefix", b"address_prefix", "address_prefixes", b"address_prefixes", "delegations", b"delegations", "ip_allocations", b"ip_allocations", "name", b"name", "nat_gateway", b"nat_gateway", "network_security_group", b"network_security_group", "private_endpoint_network_policies", b"private_endpoint_network_policies", "private_link_service_network_policies", b"private_link_service_network_policies", "resource_info", b"resource_info", "route_table", b"route_table", "service_endpoint_policies", b"service_endpoint_policies", "service_endpoints", b"service_endpoints"]) -> None: ...

global___VirtualNetworksSubnets = VirtualNetworksSubnets

@typing_extensions.final
class VirtualNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    ADDRESS_SPACE_FIELD_NUMBER: builtins.int
    DHCP_OPTIONS_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_PEERINGS_FIELD_NUMBER: builtins.int
    ENABLE_DDOS_PROTECTION_FIELD_NUMBER: builtins.int
    ENABLE_VM_PROTECTION_FIELD_NUMBER: builtins.int
    DDOS_PROTECTION_PLAN_FIELD_NUMBER: builtins.int
    BGP_COMMUNITIES_FIELD_NUMBER: builtins.int
    IP_ALLOCATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def address_space(self) -> global___AddressSpace: ...
    @property
    def dhcp_options(self) -> global___DhcpOptions: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Subnet]: ...
    @property
    def virtual_network_peerings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworkPeering]: ...
    enable_ddos_protection: builtins.bool
    enable_vm_protection: builtins.bool
    @property
    def ddos_protection_plan(self) -> global___DdosProtectionPlan: ...
    @property
    def bgp_communities(self) -> global___VirtualNetworkBgpCommunities: ...
    @property
    def ip_allocations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        address_space: global___AddressSpace | None = ...,
        dhcp_options: global___DhcpOptions | None = ...,
        subnets: collections.abc.Iterable[global___Subnet] | None = ...,
        virtual_network_peerings: collections.abc.Iterable[global___VirtualNetworkPeering] | None = ...,
        enable_ddos_protection: builtins.bool = ...,
        enable_vm_protection: builtins.bool = ...,
        ddos_protection_plan: global___DdosProtectionPlan | None = ...,
        bgp_communities: global___VirtualNetworkBgpCommunities | None = ...,
        ip_allocations: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["address_space", b"address_space", "bgp_communities", b"bgp_communities", "ddos_protection_plan", b"ddos_protection_plan", "dhcp_options", b"dhcp_options", "extended_location", b"extended_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_space", b"address_space", "bgp_communities", b"bgp_communities", "ddos_protection_plan", b"ddos_protection_plan", "dhcp_options", b"dhcp_options", "enable_ddos_protection", b"enable_ddos_protection", "enable_vm_protection", b"enable_vm_protection", "extended_location", b"extended_location", "ip_allocations", b"ip_allocations", "location", b"location", "name", b"name", "resource_info", b"resource_info", "subnets", b"subnets", "tags", b"tags", "virtual_network_peerings", b"virtual_network_peerings"]) -> None: ...

global___VirtualNetworks = VirtualNetworks

@typing_extensions.final
class VirtualNetworkPeering(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_VIRTUAL_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    ALLOW_FORWARDED_TRAFFIC_FIELD_NUMBER: builtins.int
    ALLOW_GATEWAY_TRANSIT_FIELD_NUMBER: builtins.int
    USE_REMOTE_GATEWAYS_FIELD_NUMBER: builtins.int
    REMOTE_VIRTUAL_NETWORK_FIELD_NUMBER: builtins.int
    REMOTE_ADDRESS_SPACE_FIELD_NUMBER: builtins.int
    REMOTE_BGP_COMMUNITIES_FIELD_NUMBER: builtins.int
    PEERING_STATE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    allow_virtual_network_access: builtins.bool
    allow_forwarded_traffic: builtins.bool
    allow_gateway_transit: builtins.bool
    use_remote_gateways: builtins.bool
    remote_virtual_network: builtins.str
    @property
    def remote_address_space(self) -> global___AddressSpace: ...
    @property
    def remote_bgp_communities(self) -> global___VirtualNetworkBgpCommunities: ...
    peering_state: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        allow_virtual_network_access: builtins.bool = ...,
        allow_forwarded_traffic: builtins.bool = ...,
        allow_gateway_transit: builtins.bool = ...,
        use_remote_gateways: builtins.bool = ...,
        remote_virtual_network: builtins.str = ...,
        remote_address_space: global___AddressSpace | None = ...,
        remote_bgp_communities: global___VirtualNetworkBgpCommunities | None = ...,
        peering_state: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["remote_address_space", b"remote_address_space", "remote_bgp_communities", b"remote_bgp_communities"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_forwarded_traffic", b"allow_forwarded_traffic", "allow_gateway_transit", b"allow_gateway_transit", "allow_virtual_network_access", b"allow_virtual_network_access", "name", b"name", "peering_state", b"peering_state", "remote_address_space", b"remote_address_space", "remote_bgp_communities", b"remote_bgp_communities", "remote_virtual_network", b"remote_virtual_network", "use_remote_gateways", b"use_remote_gateways"]) -> None: ...

global___VirtualNetworkPeering = VirtualNetworkPeering

@typing_extensions.final
class VirtualNetworkBgpCommunities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIRTUAL_NETWORK_COMMUNITY_FIELD_NUMBER: builtins.int
    virtual_network_community: builtins.str
    def __init__(
        self,
        *,
        virtual_network_community: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["virtual_network_community", b"virtual_network_community"]) -> None: ...

global___VirtualNetworkBgpCommunities = VirtualNetworkBgpCommunities

@typing_extensions.final
class Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    NETWORK_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_FIELD_NUMBER: builtins.int
    NAT_GATEWAY_FIELD_NUMBER: builtins.int
    SERVICE_ENDPOINTS_FIELD_NUMBER: builtins.int
    SERVICE_ENDPOINT_POLICIES_FIELD_NUMBER: builtins.int
    IP_ALLOCATIONS_FIELD_NUMBER: builtins.int
    DELEGATIONS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_NETWORK_POLICIES_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_NETWORK_POLICIES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    address_prefix: builtins.str
    @property
    def address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def network_security_group(self) -> global___NetworkSecurityGroup: ...
    @property
    def route_table(self) -> global___RouteTable: ...
    nat_gateway: builtins.str
    @property
    def service_endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceEndpointPropertiesFormat]: ...
    @property
    def service_endpoint_policies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ip_allocations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Delegation]: ...
    private_endpoint_network_policies: builtins.str
    private_link_service_network_policies: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        address_prefix: builtins.str = ...,
        address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        network_security_group: global___NetworkSecurityGroup | None = ...,
        route_table: global___RouteTable | None = ...,
        nat_gateway: builtins.str = ...,
        service_endpoints: collections.abc.Iterable[global___ServiceEndpointPropertiesFormat] | None = ...,
        service_endpoint_policies: collections.abc.Iterable[builtins.str] | None = ...,
        ip_allocations: collections.abc.Iterable[builtins.str] | None = ...,
        delegations: collections.abc.Iterable[global___Delegation] | None = ...,
        private_endpoint_network_policies: builtins.str = ...,
        private_link_service_network_policies: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_security_group", b"network_security_group", "route_table", b"route_table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_prefix", b"address_prefix", "address_prefixes", b"address_prefixes", "delegations", b"delegations", "ip_allocations", b"ip_allocations", "name", b"name", "nat_gateway", b"nat_gateway", "network_security_group", b"network_security_group", "private_endpoint_network_policies", b"private_endpoint_network_policies", "private_link_service_network_policies", b"private_link_service_network_policies", "route_table", b"route_table", "service_endpoint_policies", b"service_endpoint_policies", "service_endpoints", b"service_endpoints"]) -> None: ...

global___Subnet = Subnet

@typing_extensions.final
class Delegation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    service_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        service_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "service_name", b"service_name"]) -> None: ...

global___Delegation = Delegation

@typing_extensions.final
class ServiceEndpointPropertiesFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    service: builtins.str
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        locations: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locations", b"locations", "service", b"service"]) -> None: ...

global___ServiceEndpointPropertiesFormat = ServiceEndpointPropertiesFormat

@typing_extensions.final
class DhcpOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_SERVERS_FIELD_NUMBER: builtins.int
    @property
    def dns_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dns_servers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_servers", b"dns_servers"]) -> None: ...

global___DhcpOptions = DhcpOptions

@typing_extensions.final
class AddressSpace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    @property
    def address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_prefixes", b"address_prefixes"]) -> None: ...

global___AddressSpace = AddressSpace

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_ssl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_ssl.proto\x12\x1boak9.tython.gcp.compute_ssl\x1a\x13shared/shared.proto\"@\n\x1e\x43omputeSslCertificateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe5\x02\n\x15\x43omputeSslCertificate\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0bname_prefix\x18\x07 \x01(\t\x12\x13\n\x0bprivate_key\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12M\n\x08timeouts\x18\x0b \x01(\x0b\x32;.oak9.tython.gcp.compute_ssl.ComputeSslCertificateXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"K\n\x19\x43omputeSslPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf6\x02\n\x10\x43omputeSslPolicy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x17\n\x0f\x63ustom_features\x18\x02 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10\x65nabled_features\x18\x04 \x03(\t\x12\x13\n\x0b\x66ingerprint\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x17\n\x0fmin_tls_version\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07profile\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x11\n\tself_link\x18\x0b \x01(\t\x12H\n\x08timeouts\x18\x0c \x01(\x0b\x32\x36.oak9.tython.gcp.compute_ssl.ComputeSslPolicyXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_ssl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESSLCERTIFICATEXTIMEOUTS._serialized_start=79
  _COMPUTESSLCERTIFICATEXTIMEOUTS._serialized_end=143
  _COMPUTESSLCERTIFICATE._serialized_start=146
  _COMPUTESSLCERTIFICATE._serialized_end=503
  _COMPUTESSLPOLICYXTIMEOUTS._serialized_start=505
  _COMPUTESSLPOLICYXTIMEOUTS._serialized_end=580
  _COMPUTESSLPOLICY._serialized_start=583
  _COMPUTESSLPOLICY._serialized_end=957
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeManagedSslCertificateXManaged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAINS_FIELD_NUMBER: builtins.int
    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domains", b"domains"]) -> None: ...

global___ComputeManagedSslCertificateXManaged = ComputeManagedSslCertificateXManaged

@typing_extensions.final
class ComputeManagedSslCertificateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeManagedSslCertificateXTimeouts = ComputeManagedSslCertificateXTimeouts

@typing_extensions.final
class ComputeManagedSslCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SUBJECT_ALTERNATIVE_NAMES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MANAGED_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate_id: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    expire_time: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def subject_alternative_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    type: builtins.str
    @property
    def managed(self) -> global___ComputeManagedSslCertificateXManaged: ...
    @property
    def timeouts(self) -> global___ComputeManagedSslCertificateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate_id: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        expire_time: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        subject_alternative_names: collections.abc.Iterable[builtins.str] | None = ...,
        type: builtins.str = ...,
        managed: global___ComputeManagedSslCertificateXManaged | None = ...,
        timeouts: global___ComputeManagedSslCertificateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed", b"managed", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_id", b"certificate_id", "creation_timestamp", b"creation_timestamp", "description", b"description", "expire_time", b"expire_time", "id", b"id", "managed", b"managed", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "subject_alternative_names", b"subject_alternative_names", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___ComputeManagedSslCertificate = ComputeManagedSslCertificate



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LifecyclePolicyCreateRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_UNIT_FIELD_NUMBER: builtins.int
    TIMES_FIELD_NUMBER: builtins.int
    CRON_EXPRESSION_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_unit: builtins.str
    @property
    def times(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cron_expression: builtins.str
    interval: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_unit: builtins.str = ...,
        times: collections.abc.Iterable[builtins.str] | None = ...,
        cron_expression: builtins.str = ...,
        interval: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cron_expression", b"cron_expression", "interval", b"interval", "interval_unit", b"interval_unit", "resource_info", b"resource_info", "times", b"times"]) -> None: ...

global___LifecyclePolicyCreateRule = LifecyclePolicyCreateRule

@typing_extensions.final
class LifecyclePolicyFastRestoreRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_UNIT_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONES_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_unit: builtins.str
    @property
    def availability_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    count: builtins.int
    interval: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_unit: builtins.str = ...,
        availability_zones: collections.abc.Iterable[builtins.str] | None = ...,
        count: builtins.int = ...,
        interval: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zones", b"availability_zones", "count", b"count", "interval", b"interval", "interval_unit", b"interval_unit", "resource_info", b"resource_info"]) -> None: ...

global___LifecyclePolicyFastRestoreRule = LifecyclePolicyFastRestoreRule

@typing_extensions.final
class LifecyclePolicyRetainRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_UNIT_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_unit: builtins.str
    count: builtins.int
    interval: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_unit: builtins.str = ...,
        count: builtins.int = ...,
        interval: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "interval", b"interval", "interval_unit", b"interval_unit", "resource_info", b"resource_info"]) -> None: ...

global___LifecyclePolicyRetainRule = LifecyclePolicyRetainRule

@typing_extensions.final
class LifecyclePolicyCrossRegionCopyRetainRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_UNIT_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_unit: builtins.str
    interval: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_unit: builtins.str = ...,
        interval: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["interval", b"interval", "interval_unit", b"interval_unit", "resource_info", b"resource_info"]) -> None: ...

global___LifecyclePolicyCrossRegionCopyRetainRule = LifecyclePolicyCrossRegionCopyRetainRule

@typing_extensions.final
class LifecyclePolicyCrossRegionCopyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_REGION_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    CMK_ARN_FIELD_NUMBER: builtins.int
    RETAIN_RULE_FIELD_NUMBER: builtins.int
    COPY_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_region: builtins.str
    encrypted: builtins.bool
    cmk_arn: builtins.str
    @property
    def retain_rule(self) -> global___LifecyclePolicyCrossRegionCopyRetainRule: ...
    copy_tags: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_region: builtins.str = ...,
        encrypted: builtins.bool = ...,
        cmk_arn: builtins.str = ...,
        retain_rule: global___LifecyclePolicyCrossRegionCopyRetainRule | None = ...,
        copy_tags: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "retain_rule", b"retain_rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmk_arn", b"cmk_arn", "copy_tags", b"copy_tags", "encrypted", b"encrypted", "resource_info", b"resource_info", "retain_rule", b"retain_rule", "target_region", b"target_region"]) -> None: ...

global___LifecyclePolicyCrossRegionCopyRule = LifecyclePolicyCrossRegionCopyRule

@typing_extensions.final
class LifecyclePolicySchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsToAddEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class VariableTagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_TO_ADD_FIELD_NUMBER: builtins.int
    CREATE_RULE_FIELD_NUMBER: builtins.int
    VARIABLE_TAGS_FIELD_NUMBER: builtins.int
    FAST_RESTORE_RULE_FIELD_NUMBER: builtins.int
    RETAIN_RULE_FIELD_NUMBER: builtins.int
    CROSS_REGION_COPY_RULES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COPY_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags_to_add(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def create_rule(self) -> global___LifecyclePolicyCreateRule: ...
    @property
    def variable_tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def fast_restore_rule(self) -> global___LifecyclePolicyFastRestoreRule: ...
    @property
    def retain_rule(self) -> global___LifecyclePolicyRetainRule: ...
    @property
    def cross_region_copy_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecyclePolicyCrossRegionCopyRule]: ...
    name: builtins.str
    copy_tags: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags_to_add: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        create_rule: global___LifecyclePolicyCreateRule | None = ...,
        variable_tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        fast_restore_rule: global___LifecyclePolicyFastRestoreRule | None = ...,
        retain_rule: global___LifecyclePolicyRetainRule | None = ...,
        cross_region_copy_rules: collections.abc.Iterable[global___LifecyclePolicyCrossRegionCopyRule] | None = ...,
        name: builtins.str = ...,
        copy_tags: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_rule", b"create_rule", "fast_restore_rule", b"fast_restore_rule", "resource_info", b"resource_info", "retain_rule", b"retain_rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["copy_tags", b"copy_tags", "create_rule", b"create_rule", "cross_region_copy_rules", b"cross_region_copy_rules", "fast_restore_rule", b"fast_restore_rule", "name", b"name", "resource_info", b"resource_info", "retain_rule", b"retain_rule", "tags_to_add", b"tags_to_add", "variable_tags", b"variable_tags"]) -> None: ...

global___LifecyclePolicySchedule = LifecyclePolicySchedule

@typing_extensions.final
class LifecyclePolicyParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXCLUDE_BOOT_VOLUME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    exclude_boot_volume: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        exclude_boot_volume: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_boot_volume", b"exclude_boot_volume", "resource_info", b"resource_info"]) -> None: ...

global___LifecyclePolicyParameters = LifecyclePolicyParameters

@typing_extensions.final
class LifecyclePolicyPolicyDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TargetTagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    SCHEDULES_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TARGET_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecyclePolicySchedule]: ...
    policy_type: builtins.str
    @property
    def parameters(self) -> global___LifecyclePolicyParameters: ...
    @property
    def target_tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_types: collections.abc.Iterable[builtins.str] | None = ...,
        schedules: collections.abc.Iterable[global___LifecyclePolicySchedule] | None = ...,
        policy_type: builtins.str = ...,
        parameters: global___LifecyclePolicyParameters | None = ...,
        target_tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "policy_type", b"policy_type", "resource_info", b"resource_info", "resource_types", b"resource_types", "schedules", b"schedules", "target_tags", b"target_tags"]) -> None: ...

global___LifecyclePolicyPolicyDetails = LifecyclePolicyPolicyDetails

@typing_extensions.final
class LifecyclePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXECUTION_ROLE_ARN_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    POLICY_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    execution_role_arn: builtins.str
    description: builtins.str
    state: builtins.str
    @property
    def policy_details(self) -> global___LifecyclePolicyPolicyDetails: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        execution_role_arn: builtins.str = ...,
        description: builtins.str = ...,
        state: builtins.str = ...,
        policy_details: global___LifecyclePolicyPolicyDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["policy_details", b"policy_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "execution_role_arn", b"execution_role_arn", "policy_details", b"policy_details", "resource_info", b"resource_info", "state", b"state"]) -> None: ...

global___LifecyclePolicy = LifecyclePolicy

@typing_extensions.final
class DLM(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_POLICY_FIELD_NUMBER: builtins.int
    @property
    def lifecycle_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecyclePolicy]: ...
    def __init__(
        self,
        *,
        lifecycle_policy: collections.abc.Iterable[global___LifecyclePolicy] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lifecycle_policy", b"lifecycle_policy"]) -> None: ...

global___DLM = DLM
